@@ -1,7 +1,7 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2009 Daniel C. Bünzli. All rights reserved.
-   Distributed under a BSD3 license, see license at the end of the file.
-   react release 1.2.0
+   Distributed under the ISC license, see terms at the end of the file.
+   react v1.2.1
   ---------------------------------------------------------------------------*)
 
 let err_max_rank = "maximal rank exceeded"
@@ -983,8 +983,19 @@ module S = struct
   | Const v | Smut { sv = Some v }  -> v
   | Smut { sv = None } -> failwith err_sig_undef
 
-  let stop ?strong =
-    function Const _ -> () | Smut m -> Node.stop ?strong m.snode
+  let stop ?strong = function
+  | Const _ -> ()
+  | Smut m ->
+      match m.sv with
+      | Some _ -> Node.stop ?strong m.snode
+      | None ->
+          (* The signal was dynamically created and didn't update yet. Add the
+             stop as an end of step operation. *)
+          match Step.find_unfinished (m.snode.producers ()) with
+          | c when c == Step.nil -> assert false
+          | c ->
+              let stop () = Node.stop ?strong m.snode in
+              Step.add_eop c stop
 
   let equal ?(eq = ( = )) s s' = match s, s' with
   | Const v, Const v' -> eq v v'
@@ -1421,17 +1432,12 @@ module S = struct
     | Emut m ->
         let m' = smut (rsucc m.enode) ( = ) in
         let rec p () = [ m.enode ]
-        and u c = supdate (Pervasives.not (sval m')) m' c in
+        and u c = match !(m.ev) with
+        | None -> ()
+        | Some _ -> supdate (Pervasives.not (sval m')) m' c
+        in
         E.add_dep m m'.snode;
-        (* can't use [signal] here because of semantics. *)
-        Node.bind m'.snode p u;
-        m'.sv <- Some b;
-        begin match Step.find_unfinished [m.enode] with
-        | c when c == Step.nil ->  ()
-        | c -> Step.add c m'.snode
-        end;
-        Smut m'
-
+        signal ~i:b m' p u
   end
 
   module Int = struct
@@ -1526,22 +1532,25 @@ module S = struct
     let value ?(eq = ( = )) ~default s = match s with
     | Const (Some v) -> Const v
     | Const None ->
-        let d = match default with `Init d -> d | `Always d -> d in
-        begin match d with
-        | Const d -> Const d
-        | Smut md ->
-            match Step.find_unfinished [md.snode] with
-            | c when c == Step.nil -> Const (sval md)
-            | c ->
-                let m' = smut (rsucc md.snode) eq in
-                let rec p () = [ md.snode ]
-                and u c =
-                  Node.rem_dep md.snode m'.snode;
-                  supdate (sval md) m' c;
-                  Node.stop m'.snode
-                in
-                Node.add_dep md.snode m'.snode;
-                signal m' p u
+        begin match default with
+        | `Always d -> d
+        | `Init d ->
+            begin match d with
+            | Const d -> Const d
+            | Smut md ->
+                match Step.find_unfinished [md.snode] with
+                | c when c == Step.nil -> Const (sval md)
+                | c ->
+                    let m' = smut (rsucc md.snode) eq in
+                    let rec p () = [ md.snode ]
+                    and u c =
+                      Node.rem_dep md.snode m'.snode;
+                      supdate (sval md) m' c;
+                      Node.stop m'.snode
+                    in
+                    Node.add_dep md.snode m'.snode;
+                    signal m' p u
+            end
         end
     | Smut m ->
         match default with
@@ -1673,34 +1682,17 @@ module S = struct
 end
 
 (*---------------------------------------------------------------------------
-  Copyright (c) 2009 Daniel C. Bünzli
-  All rights reserved.
+   Copyright (c) 2009 Daniel C. Bünzli
 
-  Redistribution and use in source and binary forms, with or without
-  modification, are permitted provided that the following conditions are
-  met:
+   Permission to use, copy, modify, and/or distribute this software for any
+   purpose with or without fee is hereby granted, provided that the above
+   copyright notice and this permission notice appear in all copies.
 
-  1. Redistributions of source code must retain the above copyright
-     notice, this list of conditions and the following disclaimer.
-
-  2. Redistributions in binary form must reproduce the above copyright
-     notice, this list of conditions and the following disclaimer in the
-     documentation and/or other materials provided with the
-     distribution.
-
-  3. Neither the name of Daniel C. Bünzli nor the names of
-     contributors may be used to endorse or promote products derived
-     from this software without specific prior written permission.
-
-  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ---------------------------------------------------------------------------*)
