@@ -1,7 +1,7 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2009 Daniel C. Bünzli. All rights reserved.
-   Distributed under a BSD3 license, see license at the end of the file.
-   react release 1.2.0
+   Distributed under the ISC license, see terms at the end of the file.
+   react v1.2.1
   ---------------------------------------------------------------------------*)
 
 (** Declarative events and signals.
@@ -16,7 +16,7 @@
     {{!ex}examples}. Open the module to use it, this defines only two
     types and modules in your scope.
 
-    {e Release 1.2.0 - Daniel Bünzli <daniel.buenzl i\@erratique.ch> } *)
+    {e Release v1.2.1 - %%MAINTAINER%% } *)
 
 (**    {1 Interface} *)
 
@@ -204,7 +204,7 @@ module E : sig
       the leftmost is taken and the others are lost.
       {ul
       {- \[[select el]\]{_ t} [=] \[[List.find (fun e -> ]\[[e]\]{_t}
-      [<> None) el]\]{_t}}.
+      [<> None) el]\]{_t}.}
       {- \[[select el]\]{_ t} [= None] otherwise.}}  *)
 
   val merge : ('a -> 'b -> 'a) -> 'a -> 'b event list -> 'a event
@@ -675,13 +675,13 @@ module S : sig
       Basic types are already specialized in the module {!Special}, open
       this module to use them.  *)
 
-  (** Input signature of {!S.Make} *)
+  (** Input signature of {!Make} *)
   module type EqType = sig
     type 'a t
     val equal : 'a t -> 'a t -> bool
   end
 
-  (** Output signature of {!S.Make} *)
+  (** Output signature of {!Make} *)
   module type S = sig
     type 'a v
     val create : 'a v -> 'a v signal * (?step:step -> 'a v -> unit)
@@ -779,7 +779,7 @@ end
     [v] and [None] otherwise. We write \[[e]\]{_t} the evaluation of
     this {e semantic} function at time t.
 
-    As a shortcut notation we also define []{_<t} [: 'a event -> 'a option]
+    As a shortcut notation we also define \[\]{_<t} [: 'a event -> 'a option]
     (resp. \[\]{_<=t}) to denote the last occurrence, if any, of an
     event before (resp. before or at) [t]. More precisely :
     {ul
@@ -1098,34 +1098,17 @@ let () = run ()]}
 *)
 
 (*---------------------------------------------------------------------------
-  Copyright (c) 2009 Daniel C. Bünzli
-  All rights reserved.
+   Copyright (c) 2009 Daniel C. Bünzli
 
-  Redistribution and use in source and binary forms, with or without
-  modification, are permitted provided that the following conditions are
-  met:
+   Permission to use, copy, modify, and/or distribute this software for any
+   purpose with or without fee is hereby granted, provided that the above
+   copyright notice and this permission notice appear in all copies.
 
-  1. Redistributions of source code must retain the above copyright
-     notice, this list of conditions and the following disclaimer.
-
-  2. Redistributions in binary form must reproduce the above copyright
-     notice, this list of conditions and the following disclaimer in the
-     documentation and/or other materials provided with the
-     distribution.
-
-  3. Neither the name of Daniel C. Bünzli nor the names of
-     contributors may be used to endorse or promote products derived
-     from this software without specific prior written permission.
-
-  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ---------------------------------------------------------------------------*)
