@@ -1,11 +1,12 @@
 (*---------------------------------------------------------------------------
-   Copyright (c) (c) 2009 Daniel C. Bünzli. All rights reserved.
-   Distributed under a BSD3 license, see license at the end of the file.
+   Copyright (c) 2009 Daniel C. Bünzli. All rights reserved.
+   Distributed under the ISC license, see terms at the end of the file.
+   react v1.2.1
   ---------------------------------------------------------------------------*)
 
 (* Breakout clone. *)
 
-open React;;
+open React
 
 module Log : sig               (* Logs values, signals and events to stderr. *)
   val init : unit -> unit
@@ -136,9 +137,9 @@ end = struct
   let time, send_time = E.create ()
   let key, send_key = E.create ()
   let gather () =                               (* updates primitive events. *)
-    let c = " " in
+    let c = Bytes.create 1 in
     let i = Unix.stdin in
-    let input_char i = ignore (Unix.read i c 0 1); c.[0] in
+    let input_char i = ignore (Unix.read i c 0 1); Bytes.get c 0 in
     let dt = 0.1 in
     while true do
       if Unix.select [i] [] [] dt = ([i], [], []) then send_key (input_char i);
@@ -448,34 +449,17 @@ let main () =
 let ui = main ()                               (* keep a ref. to avoid g.c. *)
 
 (*----------------------------------------------------------------------------
-  Copyright (c) 2009 Daniel C. Bünzli
-  All rights reserved.
+   Copyright (c) 2009 Daniel C. Bünzli
 
-  Redistribution and use in source and binary forms, with or without
-  modification, are permitted provided that the following conditions are
-  met:
+   Permission to use, copy, modify, and/or distribute this software for any
+   purpose with or without fee is hereby granted, provided that the above
+   copyright notice and this permission notice appear in all copies.
 
-  1. Redistributions of source code must retain the above copyright
-     notice, this list of conditions and the following disclaimer.
-
-  2. Redistributions in binary form must reproduce the above copyright
-     notice, this list of conditions and the following disclaimer in the
-     documentation and/or other materials provided with the
-     distribution.
-
-  3. Neither the name of Daniel C. Bünzli nor the names of
-     contributors may be used to endorse or promote products derived
-     from this software without specific prior written permission.
-
-  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ---------------------------------------------------------------------------*)
