@@ -1,6 +1,7 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2009 Daniel C. Bünzli. All rights reserved.
-   Distributed under a BSD3 license, see license at the end of the file.
+   Distributed under the ISC license, see terms at the end of the file.
+   react v1.2.1
   ---------------------------------------------------------------------------*)
 
 (* Tests for react's combinators.
@@ -1212,7 +1213,7 @@ let test_option () =
   let a_s23 = vals s23 [3] in
   let a_s30 = vals s30 [512;3;1024;2048] in
   let a_s31 = vals s31 [1;512;1024;2048] in
-  let a_s32 = vals s32 [512] in
+  let a_s32 = vals s32 [512;1024;2048] in
   let a_s33 = vals s33 [3] in
   set_b0 (Some 3); set_b1 None; set_d 1024; set_b0 None; set_d 2048;
   empty a_dsome;
@@ -1233,7 +1234,7 @@ let test_bool () =
   let a_flip_never = vals (S.Bool.flip false E.never) [false] in
   let a_flip = vals (S.Bool.flip true (S.changes s)) [true; false; true] in
   let dyn_flip = S.bind s (fun _ -> S.Bool.flip true (S.changes s)) in
-  let a_dyn_flip = vals dyn_flip [true; false] in
+  let a_dyn_flip = vals dyn_flip [true] in
   set_s false; set_s true; set_s true; set_s false;
   List.iter empty [a_zedge; a_sedge; ];
   List.iter empty [a_zrise; a_zfall; a_srise; a_rfall ];
@@ -1490,34 +1491,17 @@ let main () =
 let () = main ()
 
 (*----------------------------------------------------------------------------
-  Copyright (c) 2009 Daniel C. Bünzli
-  All rights reserved.
+   Copyright (c) 2009 Daniel C. Bünzli
 
-  Redistribution and use in source and binary forms, with or without
-  modification, are permitted provided that the following conditions are
-  met:
+   Permission to use, copy, modify, and/or distribute this software for any
+   purpose with or without fee is hereby granted, provided that the above
+   copyright notice and this permission notice appear in all copies.
 
-  1. Redistributions of source code must retain the above copyright
-     notice, this list of conditions and the following disclaimer.
-
-  2. Redistributions in binary form must reproduce the above copyright
-     notice, this list of conditions and the following disclaimer in the
-     documentation and/or other materials provided with the
-     distribution.
-
-  3. Neither the name of Daniel C. Bünzli nor the names of
-     contributors may be used to endorse or promote products derived
-     from this software without specific prior written permission.
-
-  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ---------------------------------------------------------------------------*)
